import matplotlib.pyplot as plt

def calculate_credit_expansion(initial_injection, reserve_ratio):
    current_injection = initial_injection
    loan_amounts = []
    total_credit_created = 0
    loan_count = 0
    
    while current_injection > 0.01:  # 무한루프 방지를 위한 최소값 설정
        loan_count += 1
        reserve_amount = current_injection * reserve_ratio
        loanable_amount = current_injection - reserve_amount
        total_credit_created += loanable_amount
        loan_amounts.append(loanable_amount)
        
        current_injection = loanable_amount
    
    total_credit_created += initial_injection  # 초기 주입금을 포함한 총 신용 팽창 계산
    
    return loan_count, total_credit_created, loan_amounts

def main():
    reserve_ratio = 0.1  # 지급준비율

    while True:
        user_input = input("초기 주입금을 입력하세요 (종료하려면 'q'를 입력): ")
        
        if user_input.lower() == 'q':
            break
        
        try:
            initial_injection = float(user_input)
            if initial_injection <= 0:
                raise ValueError("초기 주입금은 양수여야 합니다.")
        except ValueError as e:
            print(f"잘못된 입력입니다: {e}")
            continue
        
        loan_count, total_credit_created, loan_amounts = calculate_credit_expansion(initial_injection, reserve_ratio)

        print(f"초기 주입금 {initial_injection}억 원 기준으로 예비준비금이 완전히 회수되기까지 필요한 대출 횟수: {loan_count}회")
        print(f"총 신용 팽창 금액: {total_credit_created:.2f}억 원")

        # 그래프 그리기
        plt.figure(figsize=(10, 6))
        plt.plot(range(1, loan_count + 1), loan_amounts, marker='o', linestyle='-', color='b')
        plt.title('Credit Expansion Process')
        plt.xlabel('Loan Iteration')
        plt.ylabel('Loanable Amount (in 억 원)')
        plt.grid(True)
        plt.show()

if __name__ == "__main__":
    main()
